Emitter

Struct Emitter 

pub struct Emitter(/* private fields */);

Implementations

Source

impl Emitter

pub fn new() -> (Self, MessageReceiver)

pub fn emit<T: 'static + Send + Sync>( &self, component_id: ComponentId<T>, value: T, ) -> Result<(), SendError<ViewMessage>>

Emit a message to a component via a ComponentId<T>

pub async fn emit_async<T: 'static + Send + Sync>( &self, component_id: ComponentId<T>, value: T, ) -> Result<(), SendError<ViewMessage>>

Emit a message to a component via a ComponentId<T> asynchronously

pub fn try_emit<T: 'static + Send + Sync>( &self, widget_id: WidgetId, value: T, ) -> Result<(), SendError<ViewMessage>>

Try to emit a message to a component via its WidgetId. Unlike the emit function there is no type associated with the widget id, and the message will fail to deliver silently if the wrong type is used.

pub async fn try_emit_async<T: 'static + Send + Sync>( &self, widget_id: WidgetId, value: T, ) -> Result<(), SendError<ViewMessage>>

Async counterpart of try_emit.