pub enum Wrap {
Normal,
WordBreak,
}Expand description
Word wrapping strategy
Variants
Normal
Normal word wrapping. This will break text on hyphen and whitespace. Trailing whitespace is consumed if it would cause a line break.
WordBreak
Insert a newline in the middle of any text
Implementations