PaintCtx

Struct PaintCtx 

pub struct PaintCtx<'surface, Size> {
    pub clip: Option<Region>,
    /* private fields */
}
Paint context used by the widgets to paint. It works in local coordinates, translated to screen position.

Fields

clip: Option<Region>

Implementations

Source

impl<'surface> PaintCtx<'surface, Unsized>

pub fn new( surface: &'surface mut dyn WidgetRenderer, clip: Option<Region>, glyph_map: &'surface mut GlyphMap, ) -> Self

pub fn into_sized( self, size: Size, global_pos: Pos, ) -> PaintCtx<'surface, SizePos>

Create a sized context at a given position

Source

impl<'screen> PaintCtx<'screen, SizePos>

pub fn to_unsized(&mut self) -> PaintCtx<'_, Unsized>

pub fn update(&mut self, new_size: Size, new_pos: Pos)

pub fn set_clip_region(&mut self, region: Region)

This will create an intersection with any previous regions

pub fn create_region(&self) -> Region

pub fn translate_to_global(&self, local: LocalPos) -> Option<Pos>

pub fn to_glyphs<'a>(&mut self, s: &'a str) -> Glyphs<'a>

pub fn place_glyphs( &mut self, glyphs: Glyphs<'_>, pos: LocalPos, ) -> Option<LocalPos>

pub fn set_style(&mut self, style: Style, pos: LocalPos)

pub fn set_attributes(&mut self, attrs: &Attributes<'_>, pos: LocalPos)

pub fn place_glyph( &mut self, glyph: Glyph, input_pos: LocalPos, ) -> Option<LocalPos>