Struct Element

pub struct Element<'bp> {
    pub ident: &'bp str,
    /* private fields */
}

Fields

ident: &'bp str

Implementations

Source

impl<'bp> Element<'bp>

pub fn id(&self) -> WidgetId

pub fn layout( &mut self, children: LayoutForEach<'_, 'bp>, constraints: Constraints, ctx: &mut LayoutCtx<'_, 'bp>, ) -> Result<Layout>

pub fn invalidate_cache(&mut self)

pub fn position( &mut self, children: ForEach<'_, 'bp, PositionFilter>, pos: Pos, attribute_storage: &AttributeStorage<'bp>, viewport: Viewport, )

Position the element

pub fn paint( &mut self, children: ForEach<'_, 'bp, PaintFilter>, ctx: PaintCtx<'_, Unsized>, attribute_storage: &AttributeStorage<'bp>, )

Draw an element to the surface

pub fn cached_size(&self) -> Option<Size>

Return the cached size if the constraints are matching the cached constraints.

pub fn size(&self) -> Size

pub fn inner_bounds(&self) -> Region

Inner bounds in global space

pub fn bounds(&self) -> Region

Bounds in global space

pub fn to<T: 'static>(&mut self) -> &mut T

Get a mutable reference to the underlying widget of the given type

Panics

Panics if the element is of a different type

pub fn try_to<T: 'static>(&mut self) -> Option<&mut T>

Get a mutable reference to the underlying widget of the given type

pub fn to_ref<T: 'static>(&self) -> &T

Get a reference to the underlying widget of the given type

Panics

Panics if hte element is of a different type

pub fn try_to_ref<T: 'static>(&self) -> Option<&T>

Get a reference to the underlying widget of the given type

pub fn get_pos(&self) -> Pos

Get the position of the container.