Struct Style

pub struct Style {
    pub fg: Option<Color>,
    pub bg: Option<Color>,
    pub attributes: Attributes,
}
The style for a cell in a [crate::Buffer] A style is applied to ever single cell in a [crate::Buffer].

Styles do not cascade (and don’t behave like CSS). So giving a style to a parent widget does not automatically apply it to the child.

The following template would draw a red border with white text inside:

border [foreground: red]:
    text: "hi"

In the following example, if the condition is ever true, and then false the text is_false will be rendered with a red foreground.

The way to reset the foreground is to apply Color::Reset to the text.

if [cond: {{ is_true }}]:
    text [foreground: red]: "is true"
else:
    text: "is false"

Fields

fg: Option<Color>

Foreground colour.

bg: Option<Color>

Background colour.

attributes: Attributes

Attributes.

Implementations

Source

impl Style

pub const fn new() -> Self

Create a new instance of a Style:

pub fn from_cell_attribs(attributes: &Attributes<'_>) -> Self

Create an instance of Style from CellAttributes.

pub fn set_fg(&mut self, fg: Color)

Set the foreground colour

pub fn set_bg(&mut self, bg: Color)

Set the background colour

pub fn set_bold(&mut self, bold: bool)

Set the style to bold

pub fn set_italic(&mut self, italic: bool)

Set the style to italic

pub fn set_dim(&mut self, dim: bool)

Make the cell dim

pub fn set_underlined(&mut self, underlined: bool)

Make the cell underlined as long as it’s supported

pub fn set_overlined(&mut self, overlined: bool)

Make the cell overlined as long as it’s supported

pub fn set_crossed_out(&mut self, crossed_out: bool)

Make the cell crossed out as long as it’s supported

pub fn set_reversed(&mut self, inverse: bool)

Invert the foreground and background

pub fn reset() -> Self

Reset the style

pub fn merge(&mut self, other: Style)

Merge two styles: if self has no foreground the foreground from the other style is copied to self. if self has no background the background from the other style is copied to self.